@@ -1,8 +1,10 @@
 import json
 
 from django.conf import settings
+from django.contrib.auth.mixins import LoginRequiredMixin
 from django.shortcuts import get_object_or_404, redirect, render
 from django.urls import reverse
+from django.views.generic import View
 from paypal.standard.forms import PayPalEncryptedPaymentsForm, PayPalPaymentsForm
 from plans.models import Order
 
@@ -62,7 +64,7 @@ def view_that_asks_for_money(request, order_id, sandbox=False):
         "src": "1",  # make payments recur
         "sra": "1",  # reattempt payment on payment error
         "no_note": "1",  # remove extra notes (optional)
-        "item_name": order.name,
+        "item_name": f"{order.name} Order ID: {order.pk}",
         "notify_url": request.build_absolute_uri(reverse("paypal-ipn")),
         "return": request.build_absolute_uri(
             reverse("order_payment_success", kwargs={"pk": order_id})
@@ -70,6 +72,7 @@ def view_that_asks_for_money(request, order_id, sandbox=False):
         "cancel_return": request.build_absolute_uri(
             reverse("paypal-payment-failure", kwargs={"order_id": order_id}),
         ),
+        "item_number": order.pk,
         "custom": json.dumps(
             {
                 "user_plan_id": order.user.userplan.pk,
@@ -80,6 +83,9 @@ def view_that_asks_for_money(request, order_id, sandbox=False):
             },
         ),
     }
+
+    paypal_dict["custom"] = paypal_dict["custom"][:255]
+
     print(paypal_dict)
 
     # Create the instance.
@@ -99,14 +105,15 @@ def view_that_asks_for_money(request, order_id, sandbox=False):
         initial=paypal_dict,
         button_type="subscribe",
         test_mode_enabled=sandbox,
-        **form_kwargs
+        **form_kwargs,
     )
     context = {"form": form}
     return render(request, "paypal_payments/payment.html", context)
 
 
-def payment_failure(request, order_id):
-    order = get_object_or_404(Order, pk=order_id)
-    order.status = Order.STATUS.CANCELED
-    order.save()
-    return redirect(reverse("order_payment_failure", kwargs={"pk": order_id}))
+class PaymentFailureView(LoginRequiredMixin, View):
+    def get(self, request, *args, order_id=None, payment_variant=None):
+        order = get_object_or_404(Order, pk=order_id, user=request.user)
+        order.status = Order.STATUS.CANCELED
+        order.save()
+        return redirect(reverse("order_payment_failure", kwargs={"pk": order_id}))
